==> ms_fabric_cli-0.1.10-py3-none-any.whl: fabric_cli/commands/acls/fab_acls_get.py <==
# Copyright (c) Microsoft Corporation.
# Licensed under the EULA license.

import json
from argparse import Namespace
from typing import Any

from fabric_cli.client import fab_api_connection as api_connection
from fabric_cli.client import fab_api_gateway as api_gateway
from fabric_cli.client import fab_api_item as api_items
from fabric_cli.client import fab_api_onelake as api_onelake
from fabric_cli.client import fab_api_workspace as api_workspaces
from fabric_cli.core import fab_constant, fab_logger
from fabric_cli.core.fab_exceptions import FabricAPIError, FabricCLIError
from fabric_cli.core.fab_hiearchy import (
    FabricElement,
    Item,
    OneLakeItem,
    VirtualWorkspaceItem,
    Workspace,
)
from fabric_cli.core.fab_types import ItemType, VirtualWorkspaceItemType
from fabric_cli.utils import fab_jmespath as utils_jmespath
from fabric_cli.utils import fab_storage as utils_storage
from fabric_cli.utils import fab_ui as utils_ui
from fabric_cli.utils import fab_util as utils


def exec_command(args: Namespace, context: FabricElement) -> None:
    if args.query:
        args.query = utils.process_nargs(args.query)

    if isinstance(context, Workspace):
        fab_logger.log_warning(fab_constant.WARNING_FABRIC_ADMIN_ROLE)
        _get_acls_workspace(context, args)
    elif isinstance(context, Item):
        fab_logger.log_warning(fab_constant.WARNING_FABRIC_ADMIN_ROLE)
        _get_acls_item(context, args)
    elif isinstance(context, VirtualWorkspaceItem):
        fab_logger.log_warning(fab_constant.WARNING_FABRIC_ADMIN_ROLE)
        _get_acls_virtual_ws_item(context, args)
    elif (
        # OneLake security only supporting Lakehouse items
        isinstance(context, OneLakeItem)
        and context.get_parent().get_item_type() == ItemType.LAKEHOUSE
    ):
        fab_logger.log_warning(fab_constant.WARNING_ONELAKE_RBAC_ENABLED)
        _get_acls_onelake(context, args)


# Workspaces
def _get_acls_workspace(workspace: Workspace, args: Namespace) -> None:
    args.ws_id = workspace.get_id()
    response = api_workspaces.acl_list_from_workspace(args)

    if response.status_code == 200:
        data = json.loads(response.text)
        _process_query_and_export(
            data_to_query=data["value"],
            output_file_name=workspace.get_name(),
            args=args,
        )


# Virtual Workspace Items
def _get_acls_virtual_ws_item(item: VirtualWorkspaceItem, args: Namespace) -> None:
    match item.get_item_type():
        case VirtualWorkspaceItemType.GATEWAY:
            _get_acls_gateway(item, args)
        case VirtualWorkspaceItemType.CONNECTION:
            _get_acls_connection(item, args)
        case _:
            raise FabricCLIError("Not supported", fab_constant.ERROR_NOT_SUPPORTED)


# Virtual Workspace Items - Gateway
def _get_acls_gateway(gateway: VirtualWorkspaceItem, args: Namespace) -> None:
    gw_id = gateway.get_id()
    args.gw_id = gw_id

    response = api_gateway.acl_list_from_gateway(args)

    if response.status_code == 200:
        data = json.loads(response.text)
        _process_query_and_export(
            data_to_query=data["value"],
            output_file_name=gateway.get_name(),
            args=args,
        )


# Virtual Workspace Items - Connection
def _get_acls_connection(connection: VirtualWorkspaceItem, args: Namespace) -> None:
    con_id = connection.get_id()
    args.con_id = con_id

    response = api_connection.acl_list_from_connection(args)

    if response.status_code == 200:
        data = json.loads(response.text)
        _process_query_and_export(
            data_to_query=data["value"],
            output_file_name=connection.get_name(),
            args=args,
        )


# Items
def _get_acls_item(item: Item, args: Namespace) -> None:
    workspace_id = item.get_workspace_id()
    item_id = item.get_id()

    args.ws_id = workspace_id
    args.id = item_id

    response = api_items.acl_list_from_item(args)

    if response.status_code == 200:
        data = json.loads(response.text)
        _process_query_and_export(
            data_to_query=data["accessDetails"],
            output_file_name=item.get_name(),
            args=args,
        )


# OneLake - Lakehouse
def _get_acls_onelake(context: OneLakeItem, args: Namespace) -> None:
    workspace_name = context.get_workspace_name()
    workspace_id = context.get_workspace_id()
    item_id = context.get_item_id()
    item_name = context.get_parent().get_name()

    args.ws_id = workspace_id
    args.id = item_id

    try:
        response = api_onelake.acl_list_data_access_roles(args)

        if response.status_code == 200:
            data = json.loads(response.text)
            _process_query_and_export(
                data_to_query=data["value"],
                output_file_name=context.get_item_name(),
                args=args,
            )
    except FabricAPIError as e:
        if e.status_code == "BadRequest":
            fab_logger.log_error(
                f"Universal security disabled in '{item_name}'",
                f"{args.command_path}",
            )
            utils_ui.print_grey(
                f"→ Run 'open /{workspace_name}/{item_name}' and enable it"
            )
        else:
            raise e


# Utils
def _process_query_and_export(
    data_to_query: Any, output_file_name: str, args: Namespace
) -> None:
    json_path_response = utils_jmespath.search(data_to_query, args.query)

    if args.output:
        utils_storage.do_output(
            data=json_path_response, file_name=output_file_name, args=args
        )
    elif json_path_response:
        utils_ui.print_grey(json_path_response)

==> ms_fabric_cli-1.0.0-py3-none-any.whl: fabric_cli/commands/acls/fab_acls_get.py <==
# Copyright (c) Microsoft Corporation.
# Licensed under the EULA license.

import json
from argparse import Namespace
from typing import Any

from fabric_cli.client import fab_api_connection as api_connection
from fabric_cli.client import fab_api_gateway as api_gateway
from fabric_cli.client import fab_api_item as api_items
from fabric_cli.client import fab_api_onelake as api_onelake
from fabric_cli.client import fab_api_workspace as api_workspaces
from fabric_cli.core import fab_constant, fab_logger
from fabric_cli.core.fab_exceptions import FabricAPIError, FabricCLIError
from fabric_cli.core.fab_types import ItemType, VirtualWorkspaceItemType
from fabric_cli.core.hiearchy.fab_hiearchy import (
    FabricElement,
    Item,
    OneLakeItem,
    VirtualWorkspaceItem,
    Workspace,
)
from fabric_cli.utils import fab_jmespath as utils_jmespath
from fabric_cli.utils import fab_storage as utils_storage
from fabric_cli.utils import fab_ui as utils_ui
from fabric_cli.utils import fab_util as utils


def exec_command(args: Namespace, context: FabricElement) -> None:
    if args.query:
        args.query = utils.process_nargs(args.query)

    if isinstance(context, Workspace):
        fab_logger.log_warning(fab_constant.WARNING_FABRIC_ADMIN_ROLE)
        _get_acls_workspace(context, args)
    elif isinstance(context, Item):
        fab_logger.log_warning(fab_constant.WARNING_FABRIC_ADMIN_ROLE)
        _get_acls_item(context, args)
    elif isinstance(context, VirtualWorkspaceItem):
        fab_logger.log_warning(fab_constant.WARNING_FABRIC_ADMIN_ROLE)
        _get_acls_virtual_ws_item(context, args)
    elif (
        # OneLake security only supporting Lakehouse items
        isinstance(context, OneLakeItem)
        and context.item.item_type == ItemType.LAKEHOUSE
    ):
        fab_logger.log_warning(fab_constant.WARNING_ONELAKE_RBAC_ENABLED)
        _get_acls_onelake(context, args)


# Workspaces
def _get_acls_workspace(workspace: Workspace, args: Namespace) -> None:
    args.ws_id = workspace.id
    response = api_workspaces.acl_list_from_workspace(args)

    if response.status_code == 200:
        data = json.loads(response.text)
        _process_query_and_export(
            data_to_query=data["value"],
            output_file_name=workspace.name,
            args=args,
        )


# Virtual Workspace Items
def _get_acls_virtual_ws_item(item: VirtualWorkspaceItem, args: Namespace) -> None:
    match item.item_type:
        case VirtualWorkspaceItemType.GATEWAY:
            _get_acls_gateway(item, args)
        case VirtualWorkspaceItemType.CONNECTION:
            _get_acls_connection(item, args)
        case _:
            raise FabricCLIError("Not supported", fab_constant.ERROR_NOT_SUPPORTED)


# Virtual Workspace Items - Gateway
def _get_acls_gateway(gateway: VirtualWorkspaceItem, args: Namespace) -> None:
    gw_id = gateway.id
    args.gw_id = gw_id

    response = api_gateway.acl_list_from_gateway(args)

    if response.status_code == 200:
        data = json.loads(response.text)
        _process_query_and_export(
            data_to_query=data["value"],
            output_file_name=gateway.name,
            args=args,
        )


# Virtual Workspace Items - Connection
def _get_acls_connection(connection: VirtualWorkspaceItem, args: Namespace) -> None:
    con_id = connection.id
    args.con_id = con_id

    response = api_connection.acl_list_from_connection(args)

    if response.status_code == 200:
        data = json.loads(response.text)
        _process_query_and_export(
            data_to_query=data["value"],
            output_file_name=connection.name,
            args=args,
        )


# Items
def _get_acls_item(item: Item, args: Namespace) -> None:
    workspace_id = item.workspace.id
    item_id = item.id

    args.ws_id = workspace_id
    args.id = item_id

    response = api_items.acl_list_from_item(args)

    if response.status_code == 200:
        data = json.loads(response.text)
        _process_query_and_export(
            data_to_query=data["accessDetails"],
            output_file_name=item.name,
            args=args,
        )


# OneLake - Lakehouse
def _get_acls_onelake(context: OneLakeItem, args: Namespace) -> None:
    workspace_name = context.workspace.name
    workspace_id = context.workspace.id
    item_id = context.item.id
    item_name = context.item.name

    args.ws_id = workspace_id
    args.id = item_id

    try:
        response = api_onelake.acl_list_data_access_roles(args)

        if response.status_code == 200:
            data = json.loads(response.text)
            _process_query_and_export(
                data_to_query=data["value"],
                output_file_name=context.item.name,
                args=args,
            )
    except FabricAPIError as e:
        if e.status_code == "BadRequest":
            fab_logger.log_error(
                f"Universal security disabled in '{item_name}'",
                f"{args.command_path}",
            )
            utils_ui.print_grey(
                f"→ Run 'open /{workspace_name}/{item_name}' and enable it"
            )
        else:
            raise e


# Utils
def _process_query_and_export(
    data_to_query: Any, output_file_name: str, args: Namespace
) -> None:
    json_path_response = utils_jmespath.search(data_to_query, args.query)

    if args.output:
        utils_storage.do_output(
            data=json_path_response, file_name=output_file_name, args=args
        )
    elif json_path_response:
        utils_ui.print_grey(json_path_response)
